@@ -1,31 +1,36 @@
 """
+
 client/github.py: entrypoint for interaction with a GitHub repostiory.
 Copyright (c) 2020-2022 Ayoub Malek and Vanessa Sochat
+
+This source code is licensed under the terms of the MIT license.
+For a copy, see <https://opensource.org/licenses/MIT>.
+
 """
 
-import re
-import os
-import sys
 import logging
+import os
+import re
+import sys
 
-from urlchecker.main.github import clone_repo, delete_repo
-from urlchecker.core.fileproc import remove_empty
 from urlchecker.core.check import UrlChecker
+from urlchecker.core.fileproc import remove_empty
 from urlchecker.logger import print_failure
+from urlchecker.main.github import clone_repo, delete_repo
 
 logger = logging.getLogger("urlchecker")
 
 
 def main(args, extra):
     """
-    main entrypoint for running a check. We expect an args object with
+    Main entrypoint for running a check. We expect an args object with
     arguments from the main client. From here we determine the path
     to parse (or GitHub url to clone) and call the main check function
     under main/check.py
 
-    Parameters:
-      - args: the argparse ArgParser with parsed args
-      - extra: extra arguments not handled by the parser
+    Args:
+      - args  : the argparse ArgParser with parsed args
+      - extra : extra arguments not handled by the parser
     """
     path = args.path
 
@@ -60,6 +65,7 @@ def main(args, extra):
     print("               subfolder: %s" % args.subfolder)
     print("                  branch: %s" % args.branch)
     print("                 cleanup: %s" % args.cleanup)
+    print("                  serial: %s" % args.serial)
     print("              file types: %s" % file_types)
     print("                   files: %s" % files)
     print("               print all: %s" % (not args.no_print))
@@ -79,6 +85,7 @@ def main(args, extra):
         include_patterns=files,
         exclude_files=exclude_files,
         print_all=not args.no_print,
+        serial=args.serial,
     )
     check_results = checker.run(
         exclude_urls=exclude_urls,
@@ -109,11 +116,11 @@ def main(args, extra):
                 if result["failed"]:
                     print_failure(file_name + ":")
                     for url in result["failed"]:
-                        print_failure("     " + url)
+                        print_failure("     ❌️ " + url)
         else:
             print("\n\U0001F914 Uh oh... The following urls did not pass:")
             for failed_url in check_results["failed"]:
-                print_failure(failed_url)
+                print_failure("❌️ " + failed_url)
 
     # If we have failures and it's not a force pass, exit with 1
     if not args.force_pass and check_results["failed"]:
