@@ -9,25 +9,30 @@ For a copy, see <https://opensource.org/licenses/MIT>.
 
 import csv
 import os
+import random
 import re
 import sys
+from typing import Dict, List
+
 from urlchecker.core import fileproc
-from urlchecker.core.worker import Workers
 from urlchecker.core.urlproc import UrlCheckResult
+from urlchecker.core.worker import Workers
 
 
 class UrlChecker:
-    """The UrlChecker can be instantiated by a client, and then used
+    """
+    The UrlChecker can be instantiated by a client, and then used
     to parse files, extract urls, and save results.
     """
 
     def __init__(
         self,
-        path=None,
-        file_types=None,
-        exclude_files=None,
-        print_all=True,
-        include_patterns=None,
+        path: str = None,
+        file_types: List[str] = None,
+        exclude_files: List[str] = None,
+        print_all: bool = True,
+        include_patterns: List[str] = None,
+        serial: bool = False,
     ):
         """
         initiate a url checker. At init we take in preferences for
@@ -35,16 +40,22 @@ class UrlChecker:
         parameters to run a url check.
 
         Args:
-            - path             (str) : full path to the root folder to check. If not defined, no file_paths are parsed
-            - print_all        (str) : control var for whether to print all checked file names or only the ones with urls.
+            - path              (str) : full path to the root folder to check. If not defined, no file_paths are parsed.
+            - file_types       (list) : types of files to scan for links.
+            - print_all        (bool) : control var for whether to print all checked file names or only the ones with urls.
             - exclude_files    (list) : list of excluded files and patterns for flies.
             - include_patterns (list) : list of files and patterns to check.
+            - serial           (bool) : do checks in serial (no multiprocessing)
         """
         # Initiate results object, and checks lookup (holds UrlCheck) for each file
-        self.results = {"passed": set(), "failed": set(), "excluded": set()}
+        self.results = {
+            "passed": set(),
+            "failed": set(),
+            "excluded": set(),
+        }  # type: Dict[str, set]
 
         # Results organized by filename
-        self.checks = {}
+        self.checks = {}  # type: Dict[str, Dict]
 
         # Save run parameters
         self.exclude_files = exclude_files or []
@@ -53,6 +64,7 @@ class UrlChecker:
         self.path = path
         self.file_types = file_types or [".py", ".md"]
         self.file_paths = []
+        self.serial = serial
 
         # get all file paths if a path is defined
         if path:
@@ -62,21 +74,27 @@ class UrlChecker:
                 sys.exit("%s does not exist." % path)
 
             self.file_paths = fileproc.get_file_paths(
-                include_patterns=self.include_patterns,
                 base_path=path,
                 file_types=self.file_types,
                 exclude_files=self.exclude_files,
+                include_patterns=self.include_patterns,
             )
 
-    def __str__(self):
+    def __str__(self) -> str:
         if self.path:
             return "UrlChecker:%s" % self.path
         return "UrlChecker"
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return self.__str__()
 
-    def save_results(self, file_path, sep=",", header=None, relative_paths=True):
+    def save_results(
+        self,
+        file_path: str,
+        sep: str = ",",
+        header: List[str] = None,
+        relative_paths: bool = True,
+    ) -> str:
         """
         Given a check_results dictionary, a dict with "failed" and "passed" keys (
         or more generally, keys to indicate some status), save a csv
@@ -85,10 +103,10 @@ class UrlChecker:
         on error.
 
         Args:
-            - file_path (str): the file path (.csv) to save to.
-            - sep (str): the separate to use (defaults to comma)
-            - header (list): if not provided, will save URL,RESULT
-            - relative paths (bool) : save relative paths (default True)
+            - file_path       (str) : the file path (.csv) to save to.
+            - sep             (str) : the separate to use (defaults to comma)
+            - header         (list) : if not provided, will save URL,RESULT
+            - relative_paths (bool) : save relative paths (default True)
 
         Returns:
             (str) file_path: a newly saved csv with the results
@@ -143,12 +161,12 @@ class UrlChecker:
 
     def run(
         self,
-        file_paths=None,
-        exclude_patterns=None,
-        exclude_urls=None,
-        retry_count=2,
-        timeout=5,
-    ):
+        file_paths: List[str] = None,
+        exclude_patterns: List[str] = None,
+        exclude_urls: List[str] = None,
+        retry_count: int = 2,
+        timeout: int = 5,
+    ) -> Dict[str, set]:
         """
         Run the url checker given a path, excluded patterns for urls/files
         name paths or patterns, and a number of retries and timeouts.
@@ -159,10 +177,11 @@ class UrlChecker:
             - file_paths       (list) : list of file paths to run over, defaults to those generated on init.
             - exclude_urls     (list) : list of excluded urls.
             - exclude_patterns (list) : list of excluded patterns for urls.
-            - retry_count      (int) : number of retries on failed first check. Default=2.
-            - timeout          (int) : timeout to use when waiting on check feedback. Default=5.
+            - retry_count       (int) : number of retries on failed first check. Default=2.
+            - timeout           (int) : timeout to use when waiting on check feedback. Default=5.
 
-        Returns: dictionary with each of list of urls for "failed" and "passed."
+        Returns:
+            dictionary with each of list of urls for "failed" and "passed."
         """
         file_paths = file_paths or self.file_paths
 
@@ -175,24 +194,41 @@ class UrlChecker:
         funcs = {}
         workers = Workers()
 
+        # Each run should have its own port (~2k)
+        ports = list(range(8000, 9999))
+        random.shuffle(ports)
+
         # loop through files
+        results = {}
         for file_name in file_paths:
 
+            # Re-use ports if we run out
+            if not ports:
+                ports = list(range(8000, 9999))
+
             # Export parameters and functions, use the same check task for all
-            tasks[file_name] = {
+            kwargs = {
                 "file_name": file_name,
                 "exclude_patterns": exclude_patterns,
                 "exclude_urls": exclude_urls,
                 "print_all": self.print_all,
                 "retry_count": retry_count,
                 "timeout": timeout,
+                "port": ports.pop(0),
             }
+
+            if self.serial:
+                results[file_name] = check_task(**kwargs)
+                continue
+
+            tasks[file_name] = kwargs
             funcs[file_name] = check_task
 
-        results = workers.run(funcs, tasks)
+        if not self.serial:
+            results = workers.run(funcs, tasks)  # type: ignore
         if not results:
             print("\U0001F914 There were no URLs to check.")
-            sys.exit(0)
+            return self.results
 
         for file_name, result in results.items():
             self.checks[file_name] = result
@@ -218,7 +254,9 @@ def check_task(*args, **kwargs):
 
     # Check the urls
     checker.check_urls(
-        retry_count=kwargs.get("retry_count", 2), timeout=kwargs.get("timeout", 5)
+        retry_count=kwargs.get("retry_count", 2),
+        timeout=kwargs.get("timeout", 5),
+        port=kwargs.get("port"),
     )
 
     # Update flattened results
