@@ -2,7 +2,7 @@
 
 Copyright (c) 2020-2022 Ayoub Malek and Vanessa Sochat
 
-This source code is licensed under the terms of the MIT license.  
+This source code is licensed under the terms of the MIT license.
 For a copy, see <https://opensource.org/licenses/MIT>.
 
 """
@@ -10,35 +10,35 @@ For a copy, see <https://opensource.org/licenses/MIT>.
 import logging
 
 
-def print_failure(message):
+def print_failure(message: str):
     """
     Given a message string, print as a failure in red.
 
-    Parameters:
-      - message: the message to print in red (indicating failure).
+    Args:
+      - message (str): the message to print in red (indicating failure).
     """
-    print("\x1b[31m" + message + "\x1b[0m")
+    print("\033[91m" + message + "\033[0m")
 
 
-def print_success(message):
+def print_success(message: str):
     """
     Given a message string, print as a success in green.
 
-    Parameters:
-      - message: the message to print in green (indicating success).
+    Args:
+      - message (str): the message to print in green (indicating success).
     """
-    print("\x1b[32m" + message + "\x1b[0m")
+    print("\033[92m" + message + "\033[0m")
 
 
-def get_logger(name="urlchecker", level=logging.INFO):
+def get_logger(name: str = "urlchecker", level: int = logging.INFO) -> logging.Logger:
     """
     Get a default logger for the urlchecker library, meaning
     that we use name "urlchecker" and use the default logging
     level INFO
 
     Parameters:
-      - name: the name for the logger (defaults to urlchecker)
-      - level: the logging.<level> to set with setLevel()
+      - name  (str) : the name for the logger (defaults to urlchecker)
+      - level (int) : the logging.<level> to set with setLevel()
 
     Returns: logging logger
     """
