@@ -7,7 +7,7 @@ For a copy, see <https://opensource.org/licenses/MIT>.
 
 """
 
-__version__ = "0.0.28"
+__version__ = "0.0.33"
 AUTHOR = "Ayoub Malek, Vanessa Sochat"
 AUTHOR_EMAIL = "superkogito@gmail.com, vsochat@stanford.edu"
 NAME = "urlchecker"
@@ -25,6 +25,8 @@ LICENSE = "LICENSE"
 
 INSTALL_REQUIRES = (("requests", {"min_version": "2.18.4"}),)
 
+SELENIUM_REQUIRES = (("selenium", {"min_version": None}),)
+
 TESTS_REQUIRES = (("pytest", {"min_version": "4.6.2"}),)
 
-INSTALL_REQUIRES_ALL = INSTALL_REQUIRES + TESTS_REQUIRES
+INSTALL_REQUIRES_ALL = INSTALL_REQUIRES + SELENIUM_REQUIRES + TESTS_REQUIRES
